@@ -7,7 +7,7 @@ from logging import getLogger
 
 from django.conf import settings
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 LOGGER = getLogger(__name__)
 
